#!/usr/bin/python3
# -*- coding: utf-8 -*-
# @Author   : pu mingzheng <pumz_1991@126.com>
# @Time     : 2023/03/14 11:39:38
# @File     : easy_tools/base/demo - case_convert_demo.py
# @Software : python3.11 PyCharm
# @Desc     : TODO

import case_convert
